==> roboidai-1.1.12.tar.gz: roboidai-1.1.12/roboidai/lab/_track.py <==
# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

import base64, codecs
magic = 'IyBQYXJ0IG9mIHRoZSBST0JPSUQgcHJvamVjdCAtIGh0dHA6Ly9oYW1zdGVyLnNjaG9vbAojIENvcHlyaWdodCAoQykgMjAxNiBLd2FuZy1IeXVuIFBhcmsgKGFrYWlpQGt3LmFjLmtyKQojIAojIFRoaXMgbGlicmFyeSBpcyBmcmVlIHNvZnR3YXJlOyB5b3UgY2FuIHJlZGlzdHJpYnV0ZSBpdCBhbmQvb3IKIyBtb2RpZnkgaXQgdW5kZXIgdGhlIHRlcm1zIG9mIHRoZSBHTlUgTGVzc2VyIEdlbmVyYWwgUHVibGljCiMgTGljZW5zZSBhcyBwdWJsaXNoZWQgYnkgdGhlIEZyZWUgU29mdHdhcmUgRm91bmRhdGlvbjsgZWl0aGVyCiMgdmVyc2lvbiAyLjEgb2YgdGhlIExpY2Vuc2UsIG9yIChhdCB5b3VyIG9wdGlvbikgYW55IGxhdGVyIHZlcnNpb24uCiMgCiMgVGhpcyBsaWJyYXJ5IGlzIGRpc3RyaWJ1dGVkIGluIHRoZSBob3BlIHRoYXQgaXQgd2lsbCBiZSB1c2VmdWwsCiMgYnV0IFdJVEhPVVQgQU5ZIFdBUlJBTlRZOyB3aXRob3V0IGV2ZW4gdGhlIGltcGxpZWQgd2FycmFudHkgb2YKIyBNRVJDSEFOVEFCSUxJVFkgb3IgRklUTkVTUyBGT1IgQSBQQVJUSUNVTEFSIFBVUlBPU0UuICBTZWUgdGhlIEdOVQojIExlc3NlciBHZW5lcmFsIFB1YmxpYyBMaWNlbnNlIGZvciBtb3JlIGRldGFpbHMuCiMgCiMgWW91IHNob3VsZCBoYXZlIHJlY2VpdmVkIGEgY29weSBvZiB0aGUgR05VIExlc3NlciBHZW5lcmFsCiMgUHVibGljIExpY2Vuc2UgYWxvbmcgd2l0aCB0aGlzIGxpYnJhc'
love = 'ax7VTyzVT5iqPjtq3WcqTHtqT8tqTuyPvZtEaWyMFOGo2M0q2SlMFOTo3IhMTS0nJ9hYPOWozZhYPN1BFOHMJ1joTHtHTkuL2HfVSA1nKEyVQZmZPjXVlOPo3A0o24fVR1OVPNjZwRkZF0kZmN3VPOIH0RXPzygpT9lqPOwqwVXnJ1jo3W0VT51oKO5VTSmVT5jPtbXMTIzVTMcozEsqUWuL2gsrUxbnJ1uM2HfVT91qUO1qPjtL29fo3VfVTuspzShM2HfVUAspzShM2H9XQHjYQV1AFxfVUMspzShM2H9XQHjYQV1AFxfVUqcozEiq19bMJyanUD9YGRfVT1coy9upzIuCGNcBtbtVPNtq2yxqTttCFOcoJSaMF5mnTSjMIfkKDbtVPNtnTIcM2u0VQ0tnJ1uM2Hhp2uupTIoZS0XVPNtVUyiMzMmMKDtCFNjVTyzVUqcozEiq19bMJyanUDtCPNjVTIfp2HtnTIcM2u0VP0tq2yhMT93K2uynJqbqNbtVPNtPvNtVPOvo3E0o20tCFOcoJSaMIg5o2Mzp2I0BzuynJqbqPj6KDbtVPNtnUA2VQ0tL3LlYzA2qRAioT9lXTWiqUEioFjtL3LlYxACGR9FK0WUHwWVH1LcPvNtVPNtVPNtPvNtVPOvnJ5upaxtCFOwqwVhnJ5FLJ5aMFubp3LfVPubK3WuozqyJmOqYPOmK3WuozqyJmOqYPO2K3WuozqyJmOqXFjtXTuspzShM2IoZI0fVUAspzShM2IoZI0fVUMspzShM2IoZI0cXDbtVPNtnJLtoTIhXTuspzShM2HcVQ49VQD6PvNtVPNtVPNtLzyhLKW5VUj9VTA2Zv5coyWuozqyXTumqvjtXTuspzShM2IoZy0fVUAspzShM2IoZS0fVUMspzShM2IoZS0cYPNbnS9lLJ5aMIfmKFjtp19lLJ5aMIfkKFjtqy9lLJ'
god = '5nZVsxXSkpCiAgICAKICAgIGtlcm5lbCA9IG5wLm9uZXMoKDMsMyksIG5wLnVpbnQ4KQogICAgYmluYXJ5ID0gY3YyLm1vcnBob2xvZ3lFeChiaW5hcnksIGN2Mi5NT1JQSF9PUEVOLCBrZXJuZWwpCiAgICBiaW5hcnkgPSBjdjIubW9ycGhvbG9neUV4KGJpbmFyeSwgY3YyLk1PUlBIX0NMT1NFLCBrZXJuZWwpCiAgICAKICAgIGNvbnRvdXJzLCBfID0gY3YyLmZpbmRDb250b3VycyhiaW5hcnksIGN2Mi5SRVRSX0xJU1QsIGN2Mi5DSEFJTl9BUFBST1hfU0lNUExFKQogICAgYXJlYXMgPSBbY3YyLmNvbnRvdXJBcmVhKGMpIGZvciBjIGluIGNvbnRvdXJzXQogICAgaWYgYXJlYXM6CiAgICAgICAgbWF4X2luZGV4ID0gbnAuYXJnbWF4KGFyZWFzKQogICAgICAgIG1heF9hcmVhID0gYXJlYXNbbWF4X2luZGV4XQogICAgICAgIGlmIG1heF9hcmVhID4gbWluX2FyZWE6CiAgICAgICAgICAgIG1heF9jb250b3VyID0gY29udG91cnNbbWF4X2luZGV4XQogICAgICAgICAgICBjdjIuZHJhd0NvbnRvdXJzKG91dHB1dCwgY29udG91cnMsIG1heF9pbmRleCwgY29sb3IsIC0xLCBvZmZzZXQ9KDAsIHlvZmZzZXQpKQogICAgICAgICAgICBtID0gY3YyLm1vbWVudHMobWF4X2NvbnRvdXIpCiAgICAgICAgICAgIG0wMCA9IG1bJ20wMCddCiAgICAgICAgICAgIGlmIG0wMCA+IDA6CiAgICAgICAgICAgICAgICByZXR1cm4gaW50KG1bJ20xMCddIC8gbTAwKSwgaW50KG1bJ20wMSddIC8'
destiny = 'toGNjXDbtVPNtpzI0qKWhVP0kYPNgZDbXPzEyMvOznJ5xK2qlMJIhK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVTuspzShM2H9XQHjYPN3ZPxfVUAspzShM2H9XQHjYQV1AFxfVUMspzShM2H9XQHjYQV1AFxfVUqcozEiq19bMJyanUD9YGRfVT1coy9upzIuCGNcBtbtVPNtpzI0qKWhVTMcozEsqUWuL2gsrUxbnJ1uM2HfVT91qUO1qPjtXQNfZwH1YQNcYPObK3WuozqyYPOmK3WuozqyYPO2K3WuozqyYPO3nJ5xo3qsnTIcM2u0YPOgnJ5sLKWyLFxXPtcxMJLtMzyhMS9voUIyK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVTuspzShM2H9XQRkZPjtZGZjXFjtp19lLJ5aMG0bAGNfZwH1XFjtqy9lLJ5aMG0bAGNfZwH1XFjtq2yhMT93K2uynJqbqQ0gZFjtoJyhK2SlMJR9ZPx6PvNtVPOlMKE1pz4tMzyhMS90pzSwn194rFucoJSaMFjto3I0pUI0YPNbZwH1YQNfZPxfVTuspzShM2HfVUAspzShM2HfVUMspzShM2HfVUqcozEiq19bMJyanUDfVT1coy9upzIuXDbXPzEyMvOznJ5xK3WyMS90pzSwn194rFucoJSaMFjto3I0pUI0YPObK3WuozqyCFtjYPNkZPjtZGpjYPNkBQNcYPOmK3WuozqyCFt1ZPjlAGHcYPO2K3WuozqyCFt1ZPjlAGHcYPO3nJ5xo3qsnTIcM2u0CF0kYPOgnJ5sLKWyLG0jXGbXVPNtVUWyqUIlovOznJ5xK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVPtjYQNfZwH1XFjtnS9lLJ5aMFjtp19lLJ5aMFjtqy9lLJ5aMFjtq2yhMT93K2uynJqbqPjtoJyhK2SlMJRcPt=='
joy = '\x72\x6f\x74\x31\x33'
trust = eval('\x6d\x61\x67\x69\x63') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x6c\x6f\x76\x65\x2c\x20\x6a\x6f\x79\x29') + eval('\x67\x6f\x64') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x64\x65\x73\x74\x69\x6e\x79\x2c\x20\x6a\x6f\x79\x29')
eval(compile(base64.b64decode(eval('\x74\x72\x75\x73\x74')),'<string>','exec'))

==> roboidai-1.1.16.tar.gz: roboidai-1.1.16/roboidai/lab/_track.py <==
# Part of the ROBOID project - http://hamster.school
# Copyright (C) 2016 Kwang-Hyun Park (akaii@kw.ac.kr)
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General
# Public License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330,
# Boston, MA  02111-1307  USA

import base64, codecs
magic = 'IyBQYXJ0IG9mIHRoZSBST0JPSUQgcHJvamVjdCAtIGh0dHA6Ly9oYW1zdGVyLnNjaG9vbAojIENvcHlyaWdodCAoQykgMjAxNiBLd2FuZy1IeXVuIFBhcmsgKGFrYWlpQGt3LmFjLmtyKQojIAojIFRoaXMgbGlicmFyeSBpcyBmcmVlIHNvZnR3YXJlOyB5b3UgY2FuIHJlZGlzdHJpYnV0ZSBpdCBhbmQvb3IKIyBtb2RpZnkgaXQgdW5kZXIgdGhlIHRlcm1zIG9mIHRoZSBHTlUgTGVzc2VyIEdlbmVyYWwgUHVibGljCiMgTGljZW5zZSBhcyBwdWJsaXNoZWQgYnkgdGhlIEZyZWUgU29mdHdhcmUgRm91bmRhdGlvbjsgZWl0aGVyCiMgdmVyc2lvbiAyLjEgb2YgdGhlIExpY2Vuc2UsIG9yIChhdCB5b3VyIG9wdGlvbikgYW55IGxhdGVyIHZlcnNpb24uCiMgCiMgVGhpcyBsaWJyYXJ5IGlzIGRpc3RyaWJ1dGVkIGluIHRoZSBob3BlIHRoYXQgaXQgd2lsbCBiZSB1c2VmdWwsCiMgYnV0IFdJVEhPVVQgQU5ZIFdBUlJBTlRZOyB3aXRob3V0IGV2ZW4gdGhlIGltcGxpZWQgd2FycmFudHkgb2YKIyBNRVJDSEFOVEFCSUxJVFkgb3IgRklUTkVTUyBGT1IgQSBQQVJUSUNVTEFSIFBVUlBPU0UuICBTZWUgdGhlIEdOVQojIExlc3NlciBHZW5lcmFsIFB1YmxpYyBMaWNlbnNlIGZvciBtb3JlIGRldGFpbHMuCiMgCiMgWW91IHNob3VsZCBoYXZlIHJlY2VpdmVkIGEgY29weSBvZiB0aGUgR05VIExlc3NlciBHZW5lcmFsCiMgUHVibGljIExpY2Vuc2UgYWxvbmcgd2l0aCB0aGlzIGxpYnJhc'
love = 'ax7VTyzVT5iqPjtq3WcqTHtqT8tqTuyPvZtEaWyMFOGo2M0q2SlMFOTo3IhMTS0nJ9hYPOWozZhYPN1BFOHMJ1joTHtHTkuL2HfVSA1nKEyVQZmZPjXVlOPo3A0o24fVR1OVPNjZwRkZF0kZmN3VPOIH0RXPzygpT9lqPOwqwVXnJ1jo3W0VT51oKO5VTSmVT5jPtbXMTIzVTMcozEsqUWuL2gsrUxbnJ1uM2HfVT91qUO1qPjtL29fo3VfVTuspzShM2HfVUAspzShM2H9XQHjYQV1AFxfVUMspzShM2H9XQHjYQV1AFxfVUqcozEiq19bMJyanUD9YGRfVT1coy9upzIuCGNcBtbtVPNtq2yxqTttCFOcoJSaMF5mnTSjMIfkKDbtVPNtnTIcM2u0VQ0tnJ1uM2Hhp2uupTIoZS0XVPNtVUyiMzMmMKDtCFNjVTyzVUqcozEiq19bMJyanUDtCPNjVTIfp2HtnTIcM2u0VP0tq2yhMT93K2uynJqbqNbtVPNtPvNtVPOvo3E0o20tCFOcoJSaMIg5o2Mzp2I0BzuynJqbqPj6KDbtVPNtnUA2VQ0tL3LlYzA2qRAioT9lXTWiqUEioFjtL3LlYxACGR9FK0WUHwWVH1LcPvNtVPNtVPNtPvNtVPOvnJ5upaxtCFOwqwVhnJ5FLJ5aMFubp3LfVPubK3WuozqyJmOqYPOmK3WuozqyJmOqYPO2K3WuozqyJmOqXFjtXTuspzShM2IoZI0fVUAspzShM2IoZI0fVUMspzShM2IoZI0cXDbtVPNtnJLtoTIhXTuspzShM2HcVQ49VQD6PvNtVPNtVPNtLzyhLKW5VUj9VTA2Zv5coyWuozqyXTumqvjtXTuspzShM2IoZy0fVUAspzShM2IoZS0fVUMspzShM2IoZS0cYPNbnS9lLJ5aMIfmKFjtp19lLJ5aMIfkKFjtqy9lLJ'
god = '5nZVsxXSkpCiAgICAKICAgIGtlcm5lbCA9IG5wLm9uZXMoKDMsMyksIG5wLnVpbnQ4KQogICAgYmluYXJ5ID0gY3YyLm1vcnBob2xvZ3lFeChiaW5hcnksIGN2Mi5NT1JQSF9PUEVOLCBrZXJuZWwpCiAgICBiaW5hcnkgPSBjdjIubW9ycGhvbG9neUV4KGJpbmFyeSwgY3YyLk1PUlBIX0NMT1NFLCBrZXJuZWwpCiAgICAKICAgIGNvbnRvdXJzLCBfID0gY3YyLmZpbmRDb250b3VycyhiaW5hcnksIGN2Mi5SRVRSX0xJU1QsIGN2Mi5DSEFJTl9BUFBST1hfU0lNUExFKQogICAgYXJlYXMgPSBbY3YyLmNvbnRvdXJBcmVhKGMpIGZvciBjIGluIGNvbnRvdXJzXQogICAgaWYgYXJlYXM6CiAgICAgICAgbWF4X2luZGV4ID0gbnAuYXJnbWF4KGFyZWFzKQogICAgICAgIG1heF9hcmVhID0gYXJlYXNbbWF4X2luZGV4XQogICAgICAgIGlmIG1heF9hcmVhID4gbWluX2FyZWE6CiAgICAgICAgICAgIG1heF9jb250b3VyID0gY29udG91cnNbbWF4X2luZGV4XQogICAgICAgICAgICBjdjIuZHJhd0NvbnRvdXJzKG91dHB1dCwgY29udG91cnMsIG1heF9pbmRleCwgY29sb3IsIC0xLCBvZmZzZXQ9KDAsIHlvZmZzZXQpKQogICAgICAgICAgICBtID0gY3YyLm1vbWVudHMobWF4X2NvbnRvdXIpCiAgICAgICAgICAgIG0wMCA9IG1bJ20wMCddCiAgICAgICAgICAgIGlmIG0wMCA+IDA6CiAgICAgICAgICAgICAgICByZXR1cm4gaW50KG1bJ20xMCddIC8gbTAwKSwgaW50KG1bJ20wMSddIC8'
destiny = 'toGNjXDbtVPNtpzI0qKWhVP0kYPNgZDbXPzEyMvOznJ5xK2qlMJIhK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVTuspzShM2H9XQDjYPN4ZPxfVUAspzShM2H9XQHjYQV1AFxfVUMspzShM2H9XQHjYQV1AFxfVUqcozEiq19bMJyanUD9YGRfVT1coy9upzIuCGNcBtbtVPNtpzI0qKWhVTMcozEsqUWuL2gsrUxbnJ1uM2HfVT91qUO1qPjtXQNfZwH1YQNcYPObK3WuozqyYPOmK3WuozqyYPO2K3WuozqyYPO3nJ5xo3qsnTIcM2u0YPOgnJ5sLKWyLFxXPtcxMJLtMzyhMS9voUIyK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVTuspzShM2H9XQRjZPjtZGDjXFjtp19lLJ5aMG0bAGNfZwH1XFjtqy9lLJ5aMG0bAGNfZwH1XFjtq2yhMT93K2uynJqbqQ0gZFjtoJyhK2SlMJR9ZPx6PvNtVPOlMKE1pz4tMzyhMS90pzSwn194rFucoJSaMFjto3I0pUI0YPNbZwH1YQNfZPxfVTuspzShM2HfVUAspzShM2HfVUMspzShM2HfVUqcozEiq19bMJyanUDfVT1coy9upzIuXDbXPzEyMvOznJ5xK3WyMS90pzSwn194rFucoJSaMFjto3I0pUI0YPObK3WuozqyCFtjYPNkZPjtZGpjYPNkBQNcYPOmK3WuozqyCFt1ZPjlAGHcYPO2K3WuozqyCFt1ZPjlAGHcYPO3nJ5xo3qsnTIcM2u0CF0kYPOgnJ5sLKWyLG0jXGbXVPNtVUWyqUIlovOznJ5xK3ElLJAeK3u5XTygLJqyYPOiqKEjqKDfVPtjYQNfZwH1XFjtnS9lLJ5aMFjtp19lLJ5aMFjtqy9lLJ5aMFjtq2yhMT93K2uynJqbqPjtoJyhK2SlMJRcPt=='
joy = '\x72\x6f\x74\x31\x33'
trust = eval('\x6d\x61\x67\x69\x63') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x6c\x6f\x76\x65\x2c\x20\x6a\x6f\x79\x29') + eval('\x67\x6f\x64') + eval('\x63\x6f\x64\x65\x63\x73\x2e\x64\x65\x63\x6f\x64\x65\x28\x64\x65\x73\x74\x69\x6e\x79\x2c\x20\x6a\x6f\x79\x29')
eval(compile(base64.b64decode(eval('\x74\x72\x75\x73\x74')),'<string>','exec'))
